﻿using System;
using System.ComponentModel;
using System.Globalization;
using System.Windows.Forms;
using WCFServiceSample.HiraWebService;

namespace WCFServiceSample
{
    public partial class MainForm : Form
    {
        public MainForm()
        {
            InitializeComponent();
        }

        public enum SendSmsReturnType
        {
            [Description("")]
            None = -10,

            [Description("ارسال با موفقیت انجام شد")]
            SendWasSuccessful = 0,

            [Description("نام کاربر یا کلمه عبور نامعتبر می باشد")]
            InvalidUserNameOrPassword = 1,

            [Description("کاربر مسدود شده است")]
            UserBlocked = 2,

            [Description("شماره فرستنده نامعتبر است")]
            InvalidSenderNumber = 3,

            [Description("محدودیت در ارسال روزانه")]
            LimitationInDailySend = 4,

            [Description("تعداد گیرندگان حداکثر 100 شماره می باشد")]
            LimitationInRecieverCount = 5,

            [Description("خط فرسنتده غیرفعال است")]
            SenderLineIsInactive = 6,

            [Description("متن پیامک شامل کلمات فیلتر شده است")]
            SmsContentFilteredWordsIsIncluded = 7,

            [Description("اعتبار کافی نیست")]
            NoCredit = 8,

            [Description("سامانه در حال بروز رسانی است")]
            SystemBeingUpdated = 9,

            [Description("پیاده سازی نشده است")]
            NotImplemented = 10
        }

        private void btnSendSMS_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();
            long[] recId = null;
            byte[] status = null;
            var result = sendServiceClient.SendSMS(userNameTextBox.Text, passwordTextBox.Text,
                txtSend_SenderNumber.Text, new[] { txtSend_RecieverNumber.Text },
                txtSend_SmsText.Text, false, ref recId, ref status);

            if (result == (int)SendSmsReturnType.SendWasSuccessful)
            {
                MessageBox.Show("ارسال با موفقیت انجام شد");
            }
            else
            {
                MessageBox.Show(string.Format("ارسال انجام نشد، لطفا کد برگشتی ({0}) وب سرویس را بررسی نمایید", result));
            }
        }

        private void btnGetCredit_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();
            var credit = sendServiceClient.GetCredit(userNameTextBox.Text, passwordTextBox.Text);
            lblCredit.Text = Convert.ToString(credit, CultureInfo.CurrentCulture) + " پیامک";
        }

        private void btnInbox_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();

            // daryafti = 1
            // ersali = 2
            const int messageType = 1;

            var result = sendServiceClient.GetMessages(userNameTextBox.Text, passwordTextBox.Text, messageType, new[] { txtSend_SenderNumber.Text }, 1, 1);
            if (result.Length > 0)
                txtInbox_Result.Text = result[0].Content;
        }

        private void btnGetSmsStatus_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();
            var recId = Convert.ToInt32(txtStatus_RowId.Text);
            var deliveryStatus = sendServiceClient.GetDeilvery(userNameTextBox.Text, passwordTextBox.Text, recId);
            MessageBox.Show(TranslateGetDeliveryResult(deliveryStatus));
        }

        public string TranslateGetDeliveryResult(int deliveryStatus)
        {
            var result = string.Empty;
            switch (deliveryStatus)
            {
                case -5:
                    result = "براي گرفتن گزارش تحويل حداقل يک دقيقه بعد از ارسال اقدام نماييد";
                    break;
                case -4:
                    result = "به علت اينکه پيام در صف ارسال مخابرات مي باشد، امکان گرفتن گزارش تحويل وجود ندارد";
                    break;
                case -3:
                    result = "به علت اينکه مهلت يک هفته اي گرفتن گزارش پايان يافته است، امکان گرفتن گزارش تحويل  وجود ندارد";
                    break;
                case -2:
                    result = "پيام با اين کد وجود ندارد (SmsId نامعتبر است)";
                    break;
                case -1:
                    result = "خطا در ارتباط با سرويس دهنده";
                    break;
                case 0:
                    result = "ارسال شده به مخابرات";
                    break;
                case 1:
                    result = "رسيده به گوشي";
                    break;
                case 2:
                    result = "نرسيده به گوشي";
                    break;
                case 3:
                    result = "خطاي مخابراتي";
                    break;
                case 4:
                    result = "خطاي نامشخص";
                    break;
                case 5:
                    result = "رسيده به مخابرات";
                    break;
                case 6:
                    result = "نرسيده به مخابرات";
                    break;
                case 7:
                    result = "مسدود شده توسط مقصد";
                    break;
                case 8:
                    result = "نامشخص";
                    break;
                case 9:
                    result = "مخابرات پيام را مردود اعلام کرد";
                    break;
                case 10:
                    result = "کنسل شده توسط اپراتور";
                    break;
            }
            return result;
        }

        public bool CheckValidateUserNameAndPassword()
        {
            var result = true;
            if (userNameTextBox.Text == "")
            {
                MessageBox.Show("نام کاربري را وارد نماييد");
                result = false;
            }
            else if (passwordTextBox.Text == "")
            {
                MessageBox.Show("کلمه عبور را وارد نماييد");
                result = false;
            }
            return result;
        }

        private void btnSendBatchSms_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();

            int batchSmsId;
            var result = sendServiceClient.SendBatchSms(userNameTextBox.Text, passwordTextBox.Text,
                txtSend_SenderNumber.Text, new[] { txtSend_RecieverNumber.Text },
                txtSend_SmsText.Text, false, out batchSmsId);

            if (result == (int)SendSmsReturnType.SendWasSuccessful)
                MessageBox.Show(string.Format("ارسال با موفقیت انجام شد - شناسه ارسال {0}", batchSmsId));
            else
                MessageBox.Show(string.Format("ارسال انجام نشد، لطفا کد برگشتی ({0}) وب سرویس را بررسی نمایید", result));
        }

        private void btnGetBatchDelivery_Click(object sender, EventArgs e)
        {
            if (!CheckValidateUserNameAndPassword())
                return;

            var sendServiceClient = new SendServiceClient();
            var batchSmsId = Convert.ToInt32(txtBatchSmsId.Text);

            string[] cellPhoneNumbers;
            int[] deliveryStatus;

            var result = sendServiceClient.GetBatchDelivery(userNameTextBox.Text, passwordTextBox.Text, batchSmsId, 1, 10, out cellPhoneNumbers, out deliveryStatus);
            if (result == 0)
            {
                var counter = 0;
                foreach (var mobile in cellPhoneNumbers)
                {
                    MessageBox.Show(string.Format("mobile={0}, delivery status = {1}", mobile, TranslateGetDeliveryResult(deliveryStatus[counter])));
                    counter++;
                }
            }
        }
    }
}
